==> risk-center-api-0.4.36-20190516.111443-3-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/SecondReviewSearchParam.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;


import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

// 复审查询参数
@ApiModel
public class SecondReviewSearchParam extends ReqPageQuery {
	private DateRange dateRange;
	@ApiModelProperty("广告id")
	private Long advertId;
	@ApiModelProperty("广告名称")
	private String advertName;
	@ApiModelProperty("商品名称")
	private String goodsName;
	@ApiModelProperty("审核状态 0 待复审  1 已复审")
	private Integer secondReviewStatus;
	@ApiModelProperty("审核结果 1 初审通过 2 初审拒绝  3 复审通过  4 复审拒绝")
	private Integer reviewResult;
	@ApiModelProperty("初审")
	private String firstReviewer;
	@ApiModelProperty("ae")
	private String ae;
	@ApiModelProperty("销售")
	private String sale;
	@ApiModelProperty("代理商名称")
	private String agentName;
	@ApiModelProperty("广告主名称")
	private String advertMaster;
	@ApiModelProperty("行业标签")
	private String industryTag;
	@ApiModelProperty("落地页标签")
	private String promoteTag;

	public DateRange getDateRange() {
		return dateRange;
	}

	public void setDateRange(DateRange dateRange) {
		this.dateRange = dateRange;
	}

	public Long getAdvertId() {
		return advertId;
	}

	public void setAdvertId(Long advertId) {
		this.advertId = advertId;
	}

	public String getAdvertName() {
		return advertName;
	}

	public void setAdvertName(String advertName) {
		this.advertName = advertName;
	}

	public String getGoodsName() {
		return goodsName;
	}

	public void setGoodsName(String goodsName) {
		this.goodsName = goodsName;
	}

	public Integer getSecondReviewStatus() {
		return secondReviewStatus;
	}

	public void setSecondReviewStatus(Integer secondReviewStatus) {
		this.secondReviewStatus = secondReviewStatus;
	}

	public Integer getReviewResult() {
		return reviewResult;
	}

	public void setReviewResult(Integer reviewResult) {
		this.reviewResult = reviewResult;
	}

	public String getFirstReviewer() {
		return firstReviewer;
	}

	public void setFirstReviewer(String firstReviewer) {
		this.firstReviewer = firstReviewer;
	}

	public String getAe() {
		return ae;
	}

	public void setAe(String ae) {
		this.ae = ae;
	}

	public String getSale() {
		return sale;
	}

	public void setSale(String sale) {
		this.sale = sale;
	}

	public String getAgentName() {
		return agentName;
	}

	public void setAgentName(String agentName) {
		this.agentName = agentName;
	}

	public String getAdvertMaster() {
		return advertMaster;
	}

	public void setAdvertMaster(String advertMaster) {
		this.advertMaster = advertMaster;
	}

	public String getIndustryTag() {
		return industryTag;
	}

	public void setIndustryTag(String industryTag) {
		this.industryTag = industryTag;
	}

	public String getPromoteTag() {
		return promoteTag;
	}

	public void setPromoteTag(String promoteTag) {
		this.promoteTag = promoteTag;
	}
}

==> risk-center-api-0.5.5-20190718.022823-4-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/SecondReviewSearchParam.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;


import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

// 复审查询参数
@ApiModel
public class SecondReviewSearchParam extends ReqPageQuery {
	private DateRange dateRange;
	@ApiModelProperty("广告id")
	private Long advertId;
	@ApiModelProperty("广告名称")
	private String advertName;
	@ApiModelProperty("商品名称")
	private String goodsName;
	@ApiModelProperty("审核状态 0 待复审  1 已复审")
	private Integer secondReviewStatus;
	@ApiModelProperty("审核结果 1 初审通过 2 初审拒绝  3 复审通过  4 复审拒绝")
	private Integer reviewResult;
	@ApiModelProperty("初审")
	private String firstReviewer;
	@ApiModelProperty("ae")
	private String ae;
	@ApiModelProperty("销售")
	private String sale;
	@ApiModelProperty("代理商名称")
	private String agentName;
	@ApiModelProperty("广告主名称")
	private String advertMaster;
	@ApiModelProperty("行业标签")
	private String industryTag;
	@ApiModelProperty("落地页标签")
	private String promoteTag;
	@ApiModelProperty("新/老计划:0 新 1 老")
	private Integer newAdverted;

	public DateRange getDateRange() {
		return dateRange;
	}

	public void setDateRange(DateRange dateRange) {
		this.dateRange = dateRange;
	}

	public Long getAdvertId() {
		return advertId;
	}

	public void setAdvertId(Long advertId) {
		this.advertId = advertId;
	}

	public String getAdvertName() {
		return advertName;
	}

	public void setAdvertName(String advertName) {
		this.advertName = advertName;
	}

	public String getGoodsName() {
		return goodsName;
	}

	public void setGoodsName(String goodsName) {
		this.goodsName = goodsName;
	}

	public Integer getSecondReviewStatus() {
		return secondReviewStatus;
	}

	public void setSecondReviewStatus(Integer secondReviewStatus) {
		this.secondReviewStatus = secondReviewStatus;
	}

	public Integer getReviewResult() {
		return reviewResult;
	}

	public void setReviewResult(Integer reviewResult) {
		this.reviewResult = reviewResult;
	}

	public String getFirstReviewer() {
		return firstReviewer;
	}

	public void setFirstReviewer(String firstReviewer) {
		this.firstReviewer = firstReviewer;
	}

	public String getAe() {
		return ae;
	}

	public void setAe(String ae) {
		this.ae = ae;
	}

	public String getSale() {
		return sale;
	}

	public void setSale(String sale) {
		this.sale = sale;
	}

	public String getAgentName() {
		return agentName;
	}

	public void setAgentName(String agentName) {
		this.agentName = agentName;
	}

	public String getAdvertMaster() {
		return advertMaster;
	}

	public void setAdvertMaster(String advertMaster) {
		this.advertMaster = advertMaster;
	}

	public String getIndustryTag() {
		return industryTag;
	}

	public void setIndustryTag(String industryTag) {
		this.industryTag = industryTag;
	}

	public String getPromoteTag() {
		return promoteTag;
	}

	public void setPromoteTag(String promoteTag) {
		this.promoteTag = promoteTag;
	}

	public Integer getNewAdverted() {
		return newAdverted;
	}

	public void setNewAdverted(Integer newAdverted) {
		this.newAdverted = newAdverted;
	}
}
